@@ -19,7 +19,6 @@ from testwizard.commands_audio import WaitForAudioCommand
 from testwizard.commands_audio import WaitForPeakAudioCommand
 
 #Video commands
-from testwizard.commands_video import GetVideoFormatCommand
 from testwizard.commands_video import GetVideoResolutionCommand
 from testwizard.commands_video import CompareCommand
 from testwizard.commands_video import CountLastPatternMatchesCommand
@@ -42,6 +41,7 @@ from testwizard.commands_video import DetectNoMotionCommand
 from testwizard.commands_video import LoadReferenceBitmapCommand
 from testwizard.commands_video import SaveReferenceBitmapCommand
 from testwizard.commands_video import SaveRegionCommand
+from testwizard.commands_video import SnapShotCommand
 from testwizard.commands_video import SnapShotBMPCommand
 from testwizard.commands_video import SnapShotJPGCommand
 from testwizard.commands_video import StartBackgroundCaptureCommand
@@ -63,6 +63,7 @@ from testwizard.commands_mobile import Android_SendKeyCodeCommand
 from testwizard.commands_mobile import ClickElementCommand
 from testwizard.commands_mobile import ClickPositionCommand
 from testwizard.commands_mobile import CloseAppCommand
+from testwizard.commands_mobile import RemoveAppCommand
 from testwizard.commands_mobile import FindElementCommand
 from testwizard.commands_mobile import GetElementAttributeCommand
 from testwizard.commands_mobile import GetElementLocationCommand
@@ -226,7 +227,11 @@ class AndroidSetTopBox(TestObjectBase):
     
     def resetApp(self):
         self.throwIfDisposed()
-        return ResetAppCommand(self).execute()    
+        return ResetAppCommand(self).execute()
+
+    def removeApp(self, appId):
+        self.throwIfDisposed()
+        return RemoveAppCommand(self).execute(appId)    
     
     def runAppInBackground(self, seconds = None):
         self.throwIfDisposed()
@@ -313,10 +318,6 @@ class AndroidSetTopBox(TestObjectBase):
         self.throwIfDisposed()
         return CaptureReferenceBitmapCommand(self).execute()
     
-    def getVideoFormat(self):
-        self.throwIfDisposed()
-        return GetVideoFormatCommand(self).execute()
-    
     def getVideoResolution(self):
         self.throwIfDisposed()
         return GetVideoResolutionCommand(self).execute()
@@ -401,6 +402,10 @@ class AndroidSetTopBox(TestObjectBase):
         self.throwIfDisposed()
         return SaveRegionCommand(self).execute(filename)
     
+    def snapShot(self, filename, imageFormat, quality):
+        self.throwIfDisposed()
+        return SnapShotCommand(self).execute(filename, imageFormat, quality)    
+
     def snapShotBMP(self, filename):
         self.throwIfDisposed()
         return SnapShotBMPCommand(self).execute(filename)
